@@ -42,6 +42,7 @@ class TeamSerializer(serializers.ModelSerializer):
     """
     name = serializers.CharField(read_only=True, required=False)
     permission = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
@@ -57,6 +58,7 @@ class DepartmentSerializer(serializers.ModelSerializer):
     Department Serializer
     """
     name = serializers.CharField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
@@ -76,6 +78,7 @@ class FileSerializer(serializers.ModelSerializer):
     size = serializers.IntegerField(read_only=True, required=False)
     owner = serializers.CharField(read_only=True, required=False)
     shared_to = serializers.CharField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
@@ -86,36 +89,19 @@ class FileSerializer(serializers.ModelSerializer):
         read_only_fields = ['id']
 
 
-class APISerializer(serializers.ModelSerializer):
-    """
-    API Serializer
-    """
-    method = serializers.CharField(read_only=True, required=False)
-    api = serializers.CharField(read_only=True, required=False)
-    func_name = serializers.CharField(read_only=True, required=False)
-    name = serializers.CharField(read_only=True, required=False)
-    is_delete = serializers.BooleanField(read_only=True, required=False)
-    created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
-    updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
-    
-    class Meta:
-        model = models.Example
-        fields = ['id', 'method', 'api', 'func_name', 'name', 'is_delete', 'created_time', 'updated_time']
-        read_only_fields = ['id']
-
-
 class ExampleSerializer(serializers.ModelSerializer):
     """
     Example Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Example
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -138,21 +124,6 @@ class PidsSerializer(serializers.ModelSerializer):
         read_only_fields = ['pid']
 
 
-class PyPiSerializer(serializers.ModelSerializer):
-    """
-    PyPi Serializer
-    """
-    category = serializers.CharField(read_only=True, required=False)
-    date = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d')
-    percent = serializers.FloatField(read_only=True, required=False)
-    downloads = serializers.IntegerField(read_only=True, required=False)
-
-    class Meta:
-        model = models.PyPi
-        fields = ['id', 'category', 'date', 'percent', 'downloads']
-        read_only_fields = ['id']
-
-
 class CPUSerializer(serializers.ModelSerializer):
     """
     CPU Serializer
@@ -232,13 +203,14 @@ class GoodsSerializer(serializers.ModelSerializer):
     Goods Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Goods
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -247,13 +219,14 @@ class BinSerializer(serializers.ModelSerializer):
     Bin Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Bin
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -262,13 +235,30 @@ class StockSerializer(serializers.ModelSerializer):
     Stock Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Stock
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
+        read_only_fields = ['id']
+
+
+class StockBinSerializer(serializers.ModelSerializer):
+    """
+    Stock Serializer
+    """
+    data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
+    is_delete = serializers.BooleanField(read_only=True, required=False)
+    created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
+    updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
+    
+    class Meta:
+        model = models.StockBin
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -277,13 +267,14 @@ class CapitalSerializer(serializers.ModelSerializer):
     Capital Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Capital
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -292,13 +283,14 @@ class SupplierSerializer(serializers.ModelSerializer):
     Supplier Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Supplier
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -307,13 +299,14 @@ class CustomerSerializer(serializers.ModelSerializer):
     Customer Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Customer
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -322,13 +315,30 @@ class ASNSerializer(serializers.ModelSerializer):
     ASN Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.ASN
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
+        read_only_fields = ['id']
+
+
+class ASNDetailSerializer(serializers.ModelSerializer):
+    """
+    ASN Detail Serializer
+    """
+    data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
+    is_delete = serializers.BooleanField(read_only=True, required=False)
+    created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
+    updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
+    
+    class Meta:
+        model = models.ASNDetail
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -337,13 +347,30 @@ class DNSerializer(serializers.ModelSerializer):
     DN Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.DN
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
+        read_only_fields = ['id']
+
+
+class DNDetailSerializer(serializers.ModelSerializer):
+    """
+    DN Detail Serializer
+    """
+    data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
+    is_delete = serializers.BooleanField(read_only=True, required=False)
+    created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
+    updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
+    
+    class Meta:
+        model = models.DNDetail
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -352,13 +379,14 @@ class PurchaseSerializer(serializers.ModelSerializer):
     Purchase Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Purchase
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -367,13 +395,14 @@ class BarSerializer(serializers.ModelSerializer):
     Bar Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Bar
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -382,13 +411,14 @@ class FeeSerializer(serializers.ModelSerializer):
     Fee Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Fee
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
 
 
@@ -397,11 +427,12 @@ class DriverSerializer(serializers.ModelSerializer):
     Fee Serializer
     """
     data = serializers.JSONField(read_only=True, required=False)
+    project = serializers.CharField(read_only=True, required=False)
     is_delete = serializers.BooleanField(read_only=True, required=False)
     created_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     updated_time = serializers.DateTimeField(read_only=True, required=False, format='%Y-%m-%d %H:%M:%S')
     
     class Meta:
         model = models.Fee
-        fields = ['id', 'data', 'is_delete', 'created_time', 'updated_time']
+        fields = ['id', 'data', 'project', 'is_delete', 'created_time', 'updated_time']
         read_only_fields = ['id']
\ No newline at end of file
