@@ -236,32 +236,4 @@ def init_permission():
             Permission.objects.bulk_create(perm_objs, batch_size=200)
         User.objects.bulk_update(user_objs, ['permission'], batch_size=100)
     except Exception as e:
-        print(f"Error initializing permissions: {e}")
-
-def init_bomiot():
-    import socket, webbrowser
-    try:
-        User.objects.get(username='admin', is_superuser=True)
-        print('Admin user already exists, you can use admin to login:')
-    except:
-        username = 'admin'
-        email = f'{username}@bomiot.com'
-        password = username
-        admin, created = User.objects.update_or_create(email=email, username=username)
-        admin.set_password(password)
-        admin.is_active = True
-        admin.is_superuser = True
-        admin.is_staff = True
-        admin.save()
-        print('%s admin account: %s(%s), initial password: %s, just use it temporarily '
-              'and change the password for safety' % \
-              ('Created' if created else 'Reset', username, email, password))
-    print('系统启动成功')
-    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    s.connect(('8.8.8.8', 80))
-    ip = s.getsockname()[0]
-    print('本机IP地址为:', ip)
-    s.close()
-    baseurl = "http://" + ip + ":8008"
-    print('浏览器正在打开:', baseurl)
-    webbrowser.open(baseurl)
\ No newline at end of file
+        print(f"Error initializing permissions: {e}")
\ No newline at end of file
